@@ -253,7 +253,8 @@ def edit(img, *filters, scaling = 4, demo = False):
         img = pil_to_np(img)
     return img
 
-def fits(img, threshold = 64):
+def fits(img):
+    threshold = 64
     print("hello")
     if img.__class__ == numpy.ndarray:
         #should change X and Y?
